@@ -1,6 +1,6 @@
 
 import WZCMCCAPPLOGGER.GetNetWorkInfo
-import WZCMCCAPPLOGGER.LogUploader
+#import WZCMCCAPPLOGGER.LogUploader
 import requests
 import json
 
@@ -27,14 +27,16 @@ def InsertLog(APPID,loginfo):
     mac = WZCMCCAPPLOGGER.GetNetWorkInfo.get_mac_address();
     pcname = WZCMCCAPPLOGGER.GetNetWorkInfo.get_hostName();
     ip = WZCMCCAPPLOGGER.GetNetWorkInfo.get_hostip();
-
+    headers = {
+        'Content-Type': 'application/json',
+    }
     jsondata = {'APPID': APPID, 'loginfo': loginfo, 'mac': mac, 'pcname': pcname, 'ip': ip}
-    re = requests.post(url='http://'+url+'/WZGJGLLOGAPI/CMCCAPILOG/SetLog', json=jsondata)#返回
+    re = requests.post(url='http://'+url+'/WZGJGLLOGAPI/CMCCAPILOG/SetLog', data= json.dumps(jsondata),headers=headers)#返回
     result =json.loads(re.text)
     if(result['Tag']>0):
         return "添加成功"
     else:
         return "添加失败"
 
-__version__ = "0.80.0"
+__version__ = "0.81.0"
 
